==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Trim/ts/Trim_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Trim</name>
    <message>
        <location filename="../Trim.js" line="+77"/>
        <source>Choose limiting entity</source>
        <translation>Vyberte prvok PO ktorý chcete predĺžiť</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Choose entity to trim</source>
        <translation>Vyberte prvok ktorý chcete predĺžiť</translation>
    </message>
    <message>
        <location line="+169"/>
        <source>The two entities don&apos;t intersect, or are currently not supported for trimming.</source>
        <translation>Tieto dva prvky sa nepretínajú alebo nie sú podporované pre orezanie.</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Prvý prvok nie je možné orezať.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Prvok nie je možné orezať.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Druhý prvok nie je možné orezať.</translation>
    </message>
    <message>
        <location filename="../TrimInit.js" line="+2"/>
        <source>&amp;Trim</source>
        <translation>&amp;Predĺžiť</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Trim/ts/Trim_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Trim</name>
    <message>
        <location filename="../Trim.js" line="+77"/>
        <source>Choose limiting entity</source>
        <translation>Vyberte prvok PO ktorý chcete predĺžiť</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Choose entity to trim</source>
        <translation>Vyberte prvok ktorý chcete predĺžiť</translation>
    </message>
    <message>
        <location line="+169"/>
        <source>The two entities don&apos;t intersect, or are currently not supported for trimming.</source>
        <translation>Tieto dva prvky sa nepretínajú alebo nie sú podporované pre orezanie.</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Prvý prvok nie je možné orezať.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Prvok nie je možné orezať.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Druhý prvok nie je možné orezať.</translation>
    </message>
    <message>
        <location filename="../TrimInit.js" line="+2"/>
        <source>&amp;Trim</source>
        <translation>&amp;Predĺžiť po</translation>
    </message>
</context>
</TS>
